@@ -106,8 +106,7 @@ impl Client {
 
         // Finally we can send the mutation to the network's replicas
         let cmd = DataCmd::Register(RegisterWrite::Edit(op));
-
-        self.pay_and_send_data_command(cmd).await?;
+        self.send_cmd(cmd).await?;
 
         Ok(hash)
     }
@@ -119,9 +118,9 @@ impl Client {
         data: Register,
     ) -> Result<(), Error> {
         debug!("Attempting to pay and write a Register to the network");
-        let cmd = DataCmd::Register(RegisterWrite::New(data));
 
-        self.pay_and_send_data_command(cmd).await
+        let cmd = DataCmd::Register(RegisterWrite::New(data));
+        self.send_cmd(cmd).await
     }
 
     //----------------------
@@ -273,6 +272,7 @@ mod tests {
             let _value1_hash = run_w_backoff_delayed(
                 || client.write_to_register(address, value_1.clone(), BTreeSet::new()),
                 10,
+                1,
             )
             .await?;
 
@@ -303,7 +303,7 @@ mod tests {
             .store_private_register(name, tag, owner, perms)
             .await?;
 
-        let register = run_w_backoff_delayed(|| client.get_register(address), 10).await?;
+        let register = run_w_backoff_delayed(|| client.get_register(address), 10, 1).await?;
 
         assert!(register.is_private());
         assert_eq!(*register.name(), name);
@@ -318,7 +318,7 @@ mod tests {
             .store_public_register(name, tag, owner, perms)
             .await?;
 
-        let register = run_w_backoff_delayed(|| client.get_register(address), 10).await?;
+        let register = run_w_backoff_delayed(|| client.get_register(address), 10, 1).await?;
 
         assert!(register.is_public());
         assert_eq!(*register.name(), name);
@@ -341,13 +341,14 @@ mod tests {
             .store_private_register(name, tag, owner, perms)
             .await?;
 
-        let register = run_w_backoff_delayed(|| client.get_register(address), 10).await?;
+        let register = run_w_backoff_delayed(|| client.get_register(address), 10, 1).await?;
 
         assert_eq!(register.size(None)?, 0);
 
         let permissions = run_w_backoff_delayed(
             || client.get_register_permissions_for_user(address, owner),
             10,
+            1,
         )
         .await?;
 
@@ -386,6 +387,7 @@ mod tests {
         let permissions = run_w_backoff_delayed(
             || client.get_register_permissions_for_user(address, owner),
             10,
+            1,
         )
         .await?;
 
@@ -430,6 +432,7 @@ mod tests {
         let value1_hash = run_w_backoff_delayed(
             || client.write_to_register(address, value_1.clone(), BTreeSet::new()),
             10,
+            1,
         )
         .await?;
 
@@ -446,6 +449,7 @@ mod tests {
         let value2_hash = run_w_backoff_delayed(
             || client.write_to_register(address, value_2.clone(), BTreeSet::new()),
             10,
+            1,
         )
         .await?;
 
@@ -458,11 +462,13 @@ mod tests {
 
         // get_register_entry
         let retrieved_value_1 =
-            run_w_backoff_delayed(|| client.get_register_entry(address, value1_hash), 10).await?;
+            run_w_backoff_delayed(|| client.get_register_entry(address, value1_hash), 10, 1)
+                .await?;
         assert_eq!(retrieved_value_1, value_1);
 
         let retrieved_value_2 =
-            run_w_backoff_delayed(|| client.get_register_entry(address, value2_hash), 10).await?;
+            run_w_backoff_delayed(|| client.get_register_entry(address, value2_hash), 10, 1)
+                .await?;
         assert_eq!(retrieved_value_2, value_2);
 
         // Requesting a hash which desn't exist throws an error
@@ -492,7 +498,7 @@ mod tests {
 
         // Assert that the data is stored.
         let current_owner =
-            run_w_backoff_delayed(|| client.get_register_owner(address), 10).await?;
+            run_w_backoff_delayed(|| client.get_register_owner(address), 10, 1).await?;
 
         assert_eq!(owner, current_owner);
 
@@ -513,7 +519,7 @@ mod tests {
             .store_private_register(name, tag, owner, perms)
             .await?;
 
-        let register = run_w_backoff_delayed(|| client.get_register(address), 10).await?;
+        let register = run_w_backoff_delayed(|| client.get_register(address), 10, 1).await?;
 
         assert!(register.is_private());
 
@@ -551,7 +557,7 @@ mod tests {
             .store_public_register(name, tag, owner, perms)
             .await?;
 
-        let register = run_w_backoff_delayed(|| client.get_register(address), 10).await?;
+        let register = run_w_backoff_delayed(|| client.get_register(address), 10, 1).await?;
         assert!(register.is_public());
 
         match client.delete_register(address).await {
